@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 5.18 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 6.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2019, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +22,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsunits.h,v 5.18 2018/01/10 08:32:14 mcalabre Exp $
+  $Id: wcsunits.h,v 6.4 2019/08/15 09:30:18 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 5.18 - C routines that implement the FITS World Coordinate System
+* WCSLIB 6.4 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -176,7 +176,7 @@
 =     beam       BEAM
 =     byte       Byte
 =     d          day, days, (D), DAY, DAYS
-=     deg        degree, degrees, DEG, DEGREE, DEGREES
+=     deg        degree, degrees, Deg, Degree, Degrees, DEG, DEGREE, DEGREES
 =     GHz        GHZ
 =     h          hr, (H), HR
 =     Hz         hz, HZ
